ams.utils.paths.DisplayablePath
===============================

.. currentmodule:: ams.utils.paths

.. autoclass:: DisplayablePath

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~DisplayablePath.displayable
       
       
          ~DisplayablePath.make_tree
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~DisplayablePath.display_filename_prefix_last
      ~DisplayablePath.display_filename_prefix_middle
      ~DisplayablePath.display_parent_prefix_last
      ~DisplayablePath.display_parent_prefix_middle
      ~DisplayablePath.displayname
   
   